function getShader(cell)
	local numShaders = 8
	local g = cell.genes[4]
	local shaderID = math.ceil(numShaders*(g[1]-1)/(bpMaxSize-1))
	shaderNames = {"none","sine","sunburst","plaid","stripes","rings","warps","chaos"}
	local shiny = false
	if round(cell.genes[4][geneSize]*10) == 88 then shiny = true end
	if shaderNames[shaderID]=="none" then
		cell.shader = love.graphics.newShader[[
			extern number w;
			extern number h;
			extern number s;
			extern bool shiny;
			vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
				vec4 pixel = Texel(texture, texture_coords );

				float tws = 1/w;
				float ths = 1/h;
				vec2 tCoordsLeft;
				tCoordsLeft.x = texture_coords.x - tws;
				tCoordsLeft.y = texture_coords.y;
				vec4 pixelLeft = Texel(texture, tCoordsLeft);
				vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;
				tCoordsRight.y = texture_coords.y;
				vec4 pixelRight = Texel(texture, tCoordsRight);
				vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;
				tCoordsUp.y = texture_coords.y+ths;
				vec4 pixelUp = Texel(texture, tCoordsUp);
				vec2 tCoordsDown;
				tCoordsDown.x = texture_coords.x;
				tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);
				bool edge = false;
				if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){
					edge = true;
				}
				if (texture_coords.x < tws || texture_coords.x > 1-tws){
					edge = true;
				}
				if (texture_coords.y < ths || texture_coords.y > 1-ths){
					edge = true;
				}
				if (pixel.a >= 1){
					if (edge) {
						pixel.rgb = pixel.rgb*1.2;
					} else {
						float xp = mod(floor(screen_coords.x),s)/s;
						float yp = 1-mod(floor(screen_coords.y),s)/s;
						float contrast = 0.2;
						float v = contrast*xp*yp;
						pixel.rgb = pixel.rgb+v-contrast/2;
					}
				}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

				return pixel;
			}]]
		cell.shader:send("s",pixelSize)
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)

	elseif shaderNames[shaderID]=="sine" then
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number m;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			  	vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
			  	float tx = floor(texture_coords.x*w);
			  	float ty = floor(texture_coords.y*h);
				float cx = floor(w/2);
				float cy = floor(h/2);
				float xd = cx-tx;
				float yd = cy-ty;
				float d = sqrt(xd*xd + yd*yd);
				float angle = atan(yd,xd);
				if (pixel.a >= 1){
					if (d < abs(n*sin(m*angle))){
						pixel.rgb = pixel.rgb*0.85;
					} else {
						pixel.rgb = pixel.rgb*1.15;
					}
				}

				float tws = 1/w;
				float ths = 1/h;
				vec2 tCoordsLeft;
				tCoordsLeft.x = texture_coords.x - tws;
				tCoordsLeft.y = texture_coords.y;
				vec4 pixelLeft = Texel(texture, tCoordsLeft);
				vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;
				tCoordsRight.y = texture_coords.y;
				vec4 pixelRight = Texel(texture, tCoordsRight);
				vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;
				tCoordsUp.y = texture_coords.y+ths;
				vec4 pixelUp = Texel(texture, tCoordsUp);
				vec2 tCoordsDown;
				tCoordsDown.x = texture_coords.x;
				tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);
				bool edge = false;
				if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){
					edge = true;
				}
				if (texture_coords.x < tws || texture_coords.x > 1-tws){
					edge = true;
				}
				if (texture_coords.y < ths || texture_coords.y > 1-ths){
					edge = true;
				}
				if (pixel.a >= 1){
					if (edge) {
						pixel.rgb = pixel.rgb*1.2;
					}
				}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

				return pixel;
		  }
		]]
		cell.shader:send("n",math.floor(cell.highestPeak/pixelSize)-1)
		cell.shader:send("m",round(g[2]))
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)

	elseif shaderNames[shaderID]=="sunburst" then
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			  	vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
				float tx = floor(texture_coords.x*w);
			  	float ty = floor(texture_coords.y*h);
				float cx = floor(w/2);
				float cy = floor(h/2);
				float dx = cx-tx;
				float dy = cy-ty;
			  	float rayWidth = 6.283184/n;
			  	float ang = atan(dy,dx);
			  	while (ang<0){ang = ang + 6.283184;}
				float val = mod(ceil(ang/rayWidth),2)*0.2 - 0.1;
				if (tx!=cx || ty!=cy){
					if (pixel.a >= 1){
						pixel.rgb = pixel.rgb+val;
					}
				}

				float tws = 1/w;float ths = 1/h;vec2 tCoordsLeft;tCoordsLeft.x = texture_coords.x - tws;tCoordsLeft.y = texture_coords.y;vec4 pixelLeft = Texel(texture, tCoordsLeft);vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;tCoordsRight.y = texture_coords.y;vec4 pixelRight = Texel(texture, tCoordsRight);vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;tCoordsUp.y = texture_coords.y+ths;vec4 pixelUp = Texel(texture, tCoordsUp);vec2 tCoordsDown;tCoordsDown.x = texture_coords.x;tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);bool edge = false;if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){edge = true;}if (texture_coords.x < tws || texture_coords.x > 1-tws){edge = true;}if (texture_coords.y < ths || texture_coords.y > 1-ths){edge = true;}if (pixel.a >= 1){if (edge) {pixel.rgb = pixel.rgb*1.2;}}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

			  	return pixel;
		  }
		  ]]
		cell.shader:send("n",round(g[2]/2)*2+2)
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)

	elseif shaderNames[shaderID]=="plaid" then
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			  	vec4 pixel = Texel(texture, texture_coords );
				float tx = floor(texture_coords.x*w);
			  	float ty = floor(texture_coords.y*h);
			  	float m=2.0;
			  	if (n>5.5) {m=3.0;}
				float val = 1+(0.2/m)*(mod(tx,m)-mod(ty,m));
				if (tx!=floor(w/2+0.5) || ty!=floor(h/2+0.5)){
					if (pixel.a >= 1){
						pixel.rgb = pixel.rgb/val;
					}
				}

				float tws = 1/w;float ths = 1/h;vec2 tCoordsLeft;tCoordsLeft.x = texture_coords.x - tws;tCoordsLeft.y = texture_coords.y;vec4 pixelLeft = Texel(texture, tCoordsLeft);vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;tCoordsRight.y = texture_coords.y;vec4 pixelRight = Texel(texture, tCoordsRight);vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;tCoordsUp.y = texture_coords.y+ths;vec4 pixelUp = Texel(texture, tCoordsUp);vec2 tCoordsDown;tCoordsDown.x = texture_coords.x;tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);bool edge = false;if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){edge = true;}if (texture_coords.x < tws || texture_coords.x > 1-tws){edge = true;}if (texture_coords.y < ths || texture_coords.y > 1-ths){edge = true;}if (pixel.a >= 1){if (edge) {pixel.rgb = pixel.rgb*1.2;}}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

			  	return pixel;
		  }
		  ]]
		cell.shader:send("n",g[2])
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)

	elseif shaderNames[shaderID]=="stripes" then
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number m;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			  	vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
			  	float tx = ceil(texture_coords.x*w/m);
			  	float ty = ceil(texture_coords.y*h/m);
			  	float val;
			  	if (n>5.5) {val = 1+0.2*mod(tx,2)-0.1;} else {val = 1+0.2*mod(ty,2)-0.1;}
				if (tx!=floor(w/2+0.5) || ty!=floor(h/2+0.5)){
					if (pixel.a >= 1){
						pixel.rgb = pixel.rgb*val;
					}
				}

				float tws = 1/w;float ths = 1/h;vec2 tCoordsLeft;tCoordsLeft.x = texture_coords.x - tws;tCoordsLeft.y = texture_coords.y;vec4 pixelLeft = Texel(texture, tCoordsLeft);vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;tCoordsRight.y = texture_coords.y;vec4 pixelRight = Texel(texture, tCoordsRight);vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;tCoordsUp.y = texture_coords.y+ths;vec4 pixelUp = Texel(texture, tCoordsUp);vec2 tCoordsDown;tCoordsDown.x = texture_coords.x;tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);bool edge = false;if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){edge = true;}if (texture_coords.x < tws || texture_coords.x > 1-tws){edge = true;}if (texture_coords.y < ths || texture_coords.y > 1-ths){edge = true;}if (pixel.a >= 1){if (edge) {pixel.rgb = pixel.rgb*1.2;}}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

			  	return pixel;
		  }
		  ]]
		cell.shader:send("n",g[2])
		cell.shader:send("m",round(g[3]/3))
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)

	elseif shaderNames[shaderID]=="rings" then
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			  	vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
				float tx = floor(texture_coords.x*w);
			  	float ty = floor(texture_coords.y*h);
				float cx = floor(w/2);
				float cy = floor(h/2);
				float dx = cx-tx;
				float dy = cy-ty;
			  	float ringWidth = n;
				float d = sqrt(dx*dx+dy*dy);
				float ring = ceil(d/ringWidth);
				float val = mod(ring,2)*0.2 - 0.1;
				if (tx!=cx || ty!=cy){
					if (pixel.a >= 1){
						pixel.rgb = pixel.rgb+val;
					}
				}

				float tws = 1/w;float ths = 1/h;vec2 tCoordsLeft;tCoordsLeft.x = texture_coords.x - tws;tCoordsLeft.y = texture_coords.y;vec4 pixelLeft = Texel(texture, tCoordsLeft);vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;tCoordsRight.y = texture_coords.y;vec4 pixelRight = Texel(texture, tCoordsRight);vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;tCoordsUp.y = texture_coords.y+ths;vec4 pixelUp = Texel(texture, tCoordsUp);vec2 tCoordsDown;tCoordsDown.x = texture_coords.x;tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);bool edge = false;if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){edge = true;}if (texture_coords.x < tws || texture_coords.x > 1-tws){edge = true;}if (texture_coords.y < ths || texture_coords.y > 1-ths){edge = true;}if (pixel.a >= 1){if (edge) {pixel.rgb = pixel.rgb*1.2;}}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

			  	return pixel;
		  }
		  ]]
		cell.shader:send("n",round(g[2]*0.3))
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)

	elseif shaderNames[shaderID]=="warps" then
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
				vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
				float tx = floor(texture_coords.x*w);
			  	float ty = floor(texture_coords.y*h);
				float cx = floor(w/2);
				float cy = floor(h/2);
				float dx = cx-tx;
				float dy = cy-ty;
				float ringWidth = texture_coords.x*n;
				float d = sqrt(dx*dx+dy*dy);
				float ring = ceil(d/ringWidth);
				float val = mod(ring,2)*0.2 - 0.1;
				if (tx!=cx || ty!=cy){
					if (pixel.a >= 1){
						pixel.rgb = pixel.rgb+val;
					}
				}

				float tws = 1/w;float ths = 1/h;vec2 tCoordsLeft;tCoordsLeft.x = texture_coords.x - tws;tCoordsLeft.y = texture_coords.y;vec4 pixelLeft = Texel(texture, tCoordsLeft);vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;tCoordsRight.y = texture_coords.y;vec4 pixelRight = Texel(texture, tCoordsRight);vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;tCoordsUp.y = texture_coords.y+ths;vec4 pixelUp = Texel(texture, tCoordsUp);vec2 tCoordsDown;tCoordsDown.x = texture_coords.x;tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);bool edge = false;if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){edge = true;}if (texture_coords.x < tws || texture_coords.x > 1-tws){edge = true;}if (texture_coords.y < ths || texture_coords.y > 1-ths){edge = true;}if (pixel.a >= 1){if (edge) {pixel.rgb = pixel.rgb*1.2;}}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

				return pixel;
		  }
		  ]]
		cell.shader:send("n",g[2])
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)
	elseif shaderNames[shaderID] == "chaos" then
		cell.skin = cell.genes[2][1]/(bpMaxSize*5)
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
				vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
				float tx = floor(texture_coords.x*w);
				float ty = floor(texture_coords.y*h);
				float cx = floor(w/2);
				float cy = floor(h/2);
				float dx = cx-tx;
				float dy = cy-ty;
				float ringWidth = n;
				float d = dx*dx + dy*dy;
				float ring = ceil(d/ringWidth);
				float val = mod(ring,2)*0.2 - 0.1;
				if (tx!=cx || ty!=cy){
					if (pixel.a >= 1){
						pixel.rgb = pixel.rgb+val;
					}
				}

				float tws = 1/w;float ths = 1/h;vec2 tCoordsLeft;tCoordsLeft.x = texture_coords.x - tws;tCoordsLeft.y = texture_coords.y;vec4 pixelLeft = Texel(texture, tCoordsLeft);vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;tCoordsRight.y = texture_coords.y;vec4 pixelRight = Texel(texture, tCoordsRight);vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;tCoordsUp.y = texture_coords.y+ths;vec4 pixelUp = Texel(texture, tCoordsUp);vec2 tCoordsDown;tCoordsDown.x = texture_coords.x;tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);bool edge = false;if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){edge = true;}if (texture_coords.x < tws || texture_coords.x > 1-tws){edge = true;}if (texture_coords.y < ths || texture_coords.y > 1-ths){edge = true;}if (pixel.a >= 1){if (edge) {pixel.rgb = pixel.rgb*1.25;}}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

				return pixel;
		  }
		  ]]
		cell.shader:send("n",g[2]/(g[3]*10))
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)
	end
	if round(g[geneSize]*100) == 777 then
		cell.shader = love.graphics.newShader[[
		extern number w;
		extern number h;
		vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			vec4 pixel = Texel(texture, texture_coords );
			float modH = h/4;
			float modW = w/2;
			float r = 0.9;
			float g = 0.779;
			float b = 0.0;
			float tx = texture_coords.x*(modW);
			float ty = texture_coords.y*(modH);
			float offSet = mod(floor(tx)+1,2);
			ty = ty+0.5*offSet;
			float xd = fract(tx);
			float yd = fract(ty);
			r = r + xd*yd;
			g = g + xd*yd;

			if (pixel.a>=1){
		  		float val = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
		  		r = r * val;
		  		g = g * val;
		  		b = 0.25 * val;
		  	}

		  	pixel.r = r;
		  	pixel.g = g;
		  	pixel.b = b;
			return pixel;
		}
		]]
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
	end
	if round(g[geneSize]*100) == 333 then
		cell.diamond = true
		cell.shader = love.graphics.newShader[[
		extern number n;
		extern number rot;
		vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
			pixel.r = 0.1;
			pixel.g = 0.46;
			pixel.b = 0.4;
			float dx = texture_coords.x-0.5;
			float dy =  texture_coords.y - 0.5;
			float rayWidth = 6.283184/n;
			float ang = atan(dy,dx);
			ang = ang + (rot-1)*1.5708;
			while (ang>6.283184) { ang = ang-6.283184;}
			while (ang<0) {ang = ang+6.283184;}
			float ray = floor(ang/rayWidth+0.5);
			float val = abs(ray - n/2)/n + abs(ang/rayWidth-ray)/5;
			if (pixel.a >= 1 && (abs(dx)>0.15 || abs(dy)>0.15)){
				pixel.rgb = pixel.rgb+val;
			} else {
				float val = (dx+dy)/20;
				pixel.r = 0.6+val;
				pixel.g = 0.9+val;
				pixel.b = 0.9+val;
			}

			float shine = sin((screen_coords.x+screen_coords.y)/10)*0.1 + 1;
			pixel = pixel*shine;

			return pixel;
		}
		]]
		cell.shader:send("n",4)
		cell.shader:send("rot",cell.facing)
	end
	--
	if round(g[geneSize]*10) == 66 then
		cell.isAnimated = true
		cell.skin = cell.genes[2][1]/(bpMaxSize*5)
		cell.shader = love.graphics.newShader[[
		  extern number n;
		  extern number w;
		  extern number h;
		  extern bool shiny;
		  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
				vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
				float tx = floor(texture_coords.x*w);
				float ty = floor(texture_coords.y*h);
				float cx = floor(w/2);
				float cy = floor(h/2);
				float dx = cx-tx;
				float dy = cy-ty;
				float ringWidth = n;
				float d = dx*dx + dy*dy;
				float ring = ceil(d/ringWidth);
				float val = mod(ring,2)*0.2 - 0.1;
				if (tx!=cx || ty!=cy){
					if (pixel.a >= 1){
						pixel.rgb = pixel.rgb+val;
					}
				}

				float tws = 1/w;float ths = 1/h;vec2 tCoordsLeft;tCoordsLeft.x = texture_coords.x - tws;tCoordsLeft.y = texture_coords.y;vec4 pixelLeft = Texel(texture, tCoordsLeft);vec2 tCoordsRight;tCoordsRight.x = texture_coords.x + tws;tCoordsRight.y = texture_coords.y;vec4 pixelRight = Texel(texture, tCoordsRight);vec2 tCoordsUp;tCoordsUp.x = texture_coords.x;tCoordsUp.y = texture_coords.y+ths;vec4 pixelUp = Texel(texture, tCoordsUp);vec2 tCoordsDown;tCoordsDown.x = texture_coords.x;tCoordsDown.y = texture_coords.y-ths;vec4 pixelDown = Texel(texture, tCoordsDown);bool edge = false;if (pixelLeft.a + pixelRight.a + pixelDown.a + pixelUp.a != 4){edge = true;}if (texture_coords.x < tws || texture_coords.x > 1-tws){edge = true;}if (texture_coords.y < ths || texture_coords.y > 1-ths){edge = true;}if (pixel.a >= 1){if (edge) {pixel.rgb = pixel.rgb*1.25;}}

				if(shiny){
					float shine = sin((screen_coords.x+screen_coords.y)/5)*0.15 + 0.85;
					pixel = pixel*shine;
				}

				return pixel;
		  }
		  ]]
		cell.shader:send("n",cell.skin)
		cell.shader:send("w",cell.w)
		cell.shader:send("h",cell.h)
		cell.shader:send("shiny",shiny)
		--
	end
end



flashShader = love.graphics.newShader[[
		vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords ){
			vec4 pixel = Texel(texture, texture_coords );//This is the current pixel color
			pixel.rgb = (pixel.brg + pixel.gbr)/2;
			return pixel;
		}]]
